@@ -2,8 +2,8 @@ package Moose::Meta::TypeConstraint::DuckType;
 BEGIN {
   $Moose::Meta::TypeConstraint::DuckType::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::TypeConstraint::DuckType::VERSION = '2.0200';
+{
+  $Moose::Meta::TypeConstraint::DuckType::VERSION = '2.0402';
 }
 
 use strict;
@@ -28,12 +28,14 @@ my $inliner = sub {
     my $self = shift;
     my $val  = shift;
 
-    return 'Scalar::Util::blessed(' . $val . ') '
-             . '&& Scalar::Util::blessed(' . $val . ') ne "Regexp" '
-             . '&& &List::MoreUtils::all('
-                 . 'sub { ' . $val . '->can($_) }, '
+    return $self->parent->_inline_check($val)
+         . ' && do {' . "\n"
+             . 'my $val = ' . $val . ';' . "\n"
+             . '&List::MoreUtils::all(' . "\n"
+                 . 'sub { $val->can($_) },' . "\n"
                  . join(', ', map { B::perlstring($_) } @{ $self->methods })
-             . ')';
+             . ');' . "\n"
+         . '}';
 };
 
 sub new {
@@ -44,8 +46,8 @@ sub new {
 
     my @methods = @{ $args{methods} };
     $args{constraint} = sub {
-        blessed( $_[0] ) ne 'Regexp'
-            && all { $_[0]->can($_) } @methods;
+        my $val = $_[0];
+        return all { $val->can($_) } @methods;
     };
 
     $args{inlined} = $inliner;
@@ -80,17 +82,6 @@ sub equals {
     return 1;
 }
 
-sub constraint {
-    my $self = shift;
-
-    my @methods = @{ $self->methods };
-
-    return sub {
-        my $obj = shift;
-        return all { $obj->can($_) } @methods
-    };
-}
-
 sub create_child_type {
     my ($self, @args) = @_;
     return Moose::Meta::TypeConstraint->new(@args, parent => $self);
@@ -129,7 +120,7 @@ Moose::Meta::TypeConstraint::DuckType - Type constraint for duck typing
 
 =head1 VERSION
 
-version 2.0200
+version 2.0402
 
 =head1 DESCRIPTION
 
@@ -179,11 +170,11 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2012 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
